import { Response } from 'express';
import { TwilioWebhookRequest } from './TwilioWebhookRequest';
import { SmsCookie } from '../SmsCookie';
import { Action, Message } from '../Actions';
import { ErrorHandler } from '../util';
export * from './TwilioWebhookRequest';
export interface TwilioControllerArgs {
    accountSid: string;
    authToken: string;
    cookieKey?: string;
    messageServiceId: string;
    sendOnExit: string;
}
export default class TwilioController {
    private readonly cookieKey;
    private readonly messageServiceId;
    private readonly sendOnExit;
    private readonly twilio;
    constructor({ accountSid, authToken, messageServiceId, cookieKey, sendOnExit, }: TwilioControllerArgs);
    clearSmsCookie(res: Response): void;
    getSmsCookeFromRequest(req: TwilioWebhookRequest): SmsCookie;
    handleAction(req: TwilioWebhookRequest, action: Action, handleError: ErrorHandler): Promise<void>;
    sendEmptyResponse(res: Response): void;
    sendOnMessageNotification(msg: Message, handleError: ErrorHandler): Promise<void>;
    sendSmsMessage(to: string | string[], body: string): Promise<string | string[]>;
    sendSmsResponse(res: Response, msg: string): void;
    setSmsCookie(res: Response, payload: SmsCookie): void;
}
